@@ -5,7 +5,7 @@
  *             packet encryption, packet authentication, and
  *             packet compression.
  *
- *  Copyright (C) 2002-2024 OpenVPN Technologies, Inc. <sales@openvpn.net>
+ *  Copyright (C) 2002-2026 OpenVPN Technologies, Inc. <sales@openvpn.net>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License version 2
@@ -18,8 +18,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program (see the file COPYING included with this
- *  distribution); if not, write to the Free Software Foundation, Inc.,
- *  59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *  distribution); if not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef ENV_SET_H
@@ -34,26 +33,23 @@
  * Handle environmental variable lists
  */
 
-struct env_item {
+struct env_item
+{
     char *string;
     struct env_item *next;
 };
 
-struct env_set {
+struct env_set
+{
     struct gc_arena *gc;
     struct env_item *list;
 };
 
 /* set/delete environmental variable */
-void setenv_str_ex(struct env_set *es,
-                   const char *name,
-                   const char *value,
-                   const unsigned int name_include,
-                   const unsigned int name_exclude,
-                   const char name_replace,
-                   const unsigned int value_include,
-                   const unsigned int value_exclude,
-                   const char value_replace);
+void setenv_str_ex(struct env_set *es, const char *name, const char *value,
+                   const unsigned int name_include, const unsigned int name_exclude,
+                   const char name_replace, const unsigned int value_include,
+                   const unsigned int value_exclude, const char value_replace);
 
 void setenv_counter(struct env_set *es, const char *name, counter_type value);
 
@@ -89,7 +85,15 @@ void env_set_add(struct env_set *es, const char *str);
 
 const char *env_set_get(const struct env_set *es, const char *name);
 
-void env_set_print(int msglevel, const struct env_set *es);
+void env_set_print(msglvl_t msglevel, const struct env_set *es);
+
+/**
+ * Write a struct env_set to a file. Each item on one line.
+ *
+ * @param path  The filepath to write to.
+ * @param es    Pointer to the env_set to write.
+ */
+void env_set_write_file(const char *path, const struct env_set *es);
 
 void env_set_inherit(struct env_set *es, const struct env_set *src);
 
@@ -116,8 +120,7 @@ env_safe_to_print(const char *str)
 /* returns true if environmental variable may be passed to an external program */
 bool env_allowed(const char *str);
 
-const char **make_env_array(const struct env_set *es,
-                            const bool check_allowed,
+const char **make_env_array(const struct env_set *es, const bool check_allowed,
                             struct gc_arena *gc);
 
 #endif /* ifndef ENV_SET_H */
