@@ -5,7 +5,7 @@
  *             packet encryption, packet authentication, and
  *             packet compression.
  *
- *  Copyright (C) 2002-2024 OpenVPN Inc <sales@openvpn.net>
+ *  Copyright (C) 2002-2026 OpenVPN Inc <sales@openvpn.net>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License version 2
@@ -17,8 +17,7 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License along
- *  with this program; if not, write to the Free Software Foundation, Inc.,
- *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ *  with this program; if not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef MISC_H
@@ -43,11 +42,7 @@ void set_std_files_to_null(bool stdin_only);
 
 const char **make_arg_array(const char *first, const char *parms, struct gc_arena *gc);
 
-const char **make_extended_arg_array(char **p, bool is_inline,
-                                     struct gc_arena *gc);
-
-/* prepend a random prefix to hostname */
-const char *hostname_randomize(const char *hostname, struct gc_arena *gc);
+const char **make_extended_arg_array(char **p, bool is_inline, struct gc_arena *gc);
 
 /*
  * Get and store a username/password
@@ -77,9 +72,10 @@ struct user_pass
 /*
  * Challenge response info on client as pushed by server.
  */
-struct auth_challenge_info {
-#define CR_ECHO     (1<<0)  /* echo response when typed by user */
-#define CR_RESPONSE (1<<1)  /* response needed */
+struct auth_challenge_info
+{
+#define CR_ECHO     (1 << 0) /* echo response when typed by user */
+#define CR_RESPONSE (1 << 1) /* response needed */
     unsigned int flags;
 
     const char *user;
@@ -87,50 +83,71 @@ struct auth_challenge_info {
     const char *challenge_text;
 };
 
-struct auth_challenge_info *get_auth_challenge(const char *auth_challenge, struct gc_arena *gc);
-
 /*
  * Challenge response info on client as pushed by server.
  */
-struct static_challenge_info {
-#define SC_ECHO     (1<<0)  /* echo response when typed by user */
+struct static_challenge_info
+{
+#define SC_ECHO   (1 << 0) /* echo response when typed by user */
+#define SC_CONCAT (1 << 1) /* concatenate password and response and do not base64 encode */
     unsigned int flags;
 
     const char *challenge_text;
 };
 
 #else  /* ifdef ENABLE_MANAGEMENT */
-struct auth_challenge_info {};
-struct static_challenge_info {};
+struct auth_challenge_info
+{
+};
+struct static_challenge_info
+{
+};
 #endif /* ifdef ENABLE_MANAGEMENT */
 
 /*
  * Flags for get_user_pass and management_query_user_pass
  */
-#define GET_USER_PASS_MANAGEMENT    (1<<0)
+#define GET_USER_PASS_MANAGEMENT            (1 << 0)
 /* GET_USER_PASS_SENSITIVE     (1<<1)  not used anymore */
-#define GET_USER_PASS_PASSWORD_ONLY (1<<2)
-#define GET_USER_PASS_NEED_OK       (1<<3)
-#define GET_USER_PASS_NOFATAL       (1<<4)
-#define GET_USER_PASS_NEED_STR      (1<<5)
-#define GET_USER_PASS_PREVIOUS_CREDS_FAILED (1<<6)
+#define GET_USER_PASS_PASSWORD_ONLY         (1 << 2)
+#define GET_USER_PASS_NEED_OK               (1 << 3)
+#define GET_USER_PASS_NOFATAL               (1 << 4)
+#define GET_USER_PASS_NEED_STR              (1 << 5)
+#define GET_USER_PASS_PREVIOUS_CREDS_FAILED (1 << 6)
 
-#define GET_USER_PASS_DYNAMIC_CHALLENGE      (1<<7) /* CRV1 protocol  -- dynamic challenge */
-#define GET_USER_PASS_STATIC_CHALLENGE       (1<<8) /* SCRV1 protocol -- static challenge */
-#define GET_USER_PASS_STATIC_CHALLENGE_ECHO  (1<<9) /* SCRV1 protocol -- echo response */
+#define GET_USER_PASS_DYNAMIC_CHALLENGE     (1 << 7) /**< CRV1 protocol  -- dynamic challenge */
+#define GET_USER_PASS_STATIC_CHALLENGE      (1 << 8) /**< SCRV1 protocol -- static challenge */
+#define GET_USER_PASS_STATIC_CHALLENGE_ECHO (1 << 9) /**< SCRV1 protocol -- echo response */
 
-#define GET_USER_PASS_INLINE_CREDS (1<<10)  /* indicates that auth_file is actually inline creds */
+/** indicates that auth_file is actually inline creds */
+#define GET_USER_PASS_INLINE_CREDS            (1 << 10)
+/** indicates password and response should be concatenated */
+#define GET_USER_PASS_STATIC_CHALLENGE_CONCAT (1 << 11)
 
-bool get_user_pass_cr(struct user_pass *up,
-                      const char *auth_file,
-                      const char *prefix,
-                      const unsigned int flags,
-                      const char *auth_challenge);
+/**
+ * Retrieves the user credentials from various sources depending on the flags.
+ *
+ * @param up The user_pass structure to store the retrieved credentials.
+ * @param auth_file The path to the authentication file. Might be NULL.
+ * @param prefix The prefix to prepend to user prompts.
+ * @param flags Additional flags to control the behavior of the function.
+ * @param auth_challenge The authentication challenge string.
+ * @return true if the user credentials were successfully retrieved, false otherwise.
+ */
+bool get_user_pass_cr(struct user_pass *up, const char *auth_file, const char *prefix,
+                      const unsigned int flags, const char *auth_challenge);
 
+/**
+ * Retrieves the user credentials from various sources depending on the flags.
+ *
+ * @param up The user_pass structure to store the retrieved credentials.
+ * @param auth_file The path to the authentication file. Might be NULL.
+ * @param prefix The prefix to prepend to user prompts.
+ * @param flags Additional flags to control the behavior of the function.
+ * @return true if the user credentials were successfully retrieved, false otherwise.
+ */
 static inline bool
-get_user_pass(struct user_pass *up,
-              const char *auth_file,
-              const char *prefix,
+get_user_pass(struct user_pass *up, const char *auth_file, const char *prefix,
               const unsigned int flags)
 {
     return get_user_pass_cr(up, auth_file, prefix, flags, NULL);
@@ -167,9 +184,6 @@ void set_auth_token_user(struct user_pass *tk, const char *username);
  */
 const char *safe_print(const char *str, struct gc_arena *gc);
 
-
-void configure_path(void);
-
 const char *sanitize_control_message(const char *str, struct gc_arena *gc);
 
 /*
@@ -185,46 +199,27 @@ bool validate_peer_info_line(char *line);
 
 void output_peer_info_env(struct env_set *es, const char *peer_info);
 
-/**
- * Returns the occurrences of 'delimiter' in a string +1
- * This is typically used to find out the number elements in a
- * cipher string or similar that is separated by : like
- *
- *   X25519:secp256r1:X448:secp512r1:secp384r1:brainpoolP384r1
- *
- * @param string        the string to work on
- * @param delimiter     the delimiter to count, typically ':'
- * @return              occrrences of delimiter + 1
- */
-int
-get_num_elements(const char *string, char delimiter);
-
 /**
  * Prepend a directory to a path.
  */
-struct buffer
-prepend_dir(const char *dir, const char *path, struct gc_arena *gc);
+struct buffer prepend_dir(const char *dir, const char *path, struct gc_arena *gc);
 
 /**
  * Encrypt username and password buffers in user_pass
  */
-void
-protect_user_pass(struct user_pass *up);
+void protect_user_pass(struct user_pass *up);
 
 /**
  * Decrypt username and password buffers in user_pass
  */
-void
-unprotect_user_pass(struct user_pass *up);
+void unprotect_user_pass(struct user_pass *up);
 
 
-#define _STRINGIFY(S) #S
+#define _STRINGIFY(S)       #S
 /* *INDENT-OFF* - uncrustify need to ignore this macro */
-#define MAC_FMT _STRINGIFY(%02hhx:%02hhx:%02hhx:%02hhx:%02hhx:%02hhx)
+#define MAC_FMT             _STRINGIFY(%02hhx:%02hhx:%02hhx:%02hhx:%02hhx:%02hhx)
 /* *INDENT-ON* */
-#define MAC_PRINT_ARG(_mac) _mac[0], _mac[1], _mac[2],  \
-    _mac[3], _mac[4], _mac[5]
-#define MAC_SCAN_ARG(_mac) &_mac[0], &_mac[1], &_mac[2], \
-    &_mac[3], &_mac[4], &_mac[5]
+#define MAC_PRINT_ARG(_mac) _mac[0], _mac[1], _mac[2], _mac[3], _mac[4], _mac[5]
+#define MAC_SCAN_ARG(_mac)  &_mac[0], &_mac[1], &_mac[2], &_mac[3], &_mac[4], &_mac[5]
 
 #endif /* ifndef MISC_H */
