@@ -5,7 +5,7 @@
  *             packet encryption, packet authentication, and
  *             packet compression.
  *
- *  Copyright (C) 2002-2024 OpenVPN Inc <sales@openvpn.net>
+ *  Copyright (C) 2002-2026 OpenVPN Inc <sales@openvpn.net>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License version 2
@@ -17,8 +17,7 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License along
- *  with this program; if not, write to the Free Software Foundation, Inc.,
- *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ *  with this program; if not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -87,6 +86,5 @@ shaper_reset_wakeup(struct shaper *s)
 void
 shaper_msg(struct shaper *s)
 {
-    msg(M_INFO, "Output Traffic Shaping initialized at %d bytes per second",
-        s->bytes_per_second);
+    msg(M_INFO, "Output Traffic Shaping initialized at %d bytes per second", s->bytes_per_second);
 }
